==> haskell-network-2.8.0.0-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network
version: 2.8.0.0
id: network-2.8.0.0-JWTbamlNgQDGa4CnHHLrSE
key: network-2.8.0.0-JWTbamlNgQDGa4CnHHLrSE
license: BSD-3-Clause
maintainer: Kazu Yamamoto, Evan Borden
homepage: https://github.com/haskell/network
synopsis: Low-level networking interface
description:
    This package provides a low-level networking interface.
    .
    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:
    .
    > library
    >   build-depends: network-uri-flag
category: Network
abi: 9fd8c298450b70b8dbf9ea67d95eda09
exposed: True
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal
hidden-modules: Network.Socket.ByteString.Internal
                Network.Socket.Types Network.Socket.ByteString.IOVec
                Network.Socket.ByteString.Lazy.Posix
                Network.Socket.ByteString.MsgHdr
import-dirs: /usr/lib/ghc-8.6.5/site-local/network-2.8.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/network-2.8.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/network-2.8.0.0
hs-libraries: HSnetwork-2.8.0.0-JWTbamlNgQDGa4CnHHLrSE
include-dirs: /usr/lib/ghc-8.6.5/site-local/network-2.8.0.0/include
includes:
    HsNet.h HsNetDef.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2 unix-2.7.2.2
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces: /usr/share/doc/haskell-network/html/network.haddock
haddock-html: /usr/share/doc/haskell-network/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-2.8.0.0-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network
version: 2.8.0.0
id: network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2
key: network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2
license: BSD-3-Clause
maintainer: Kazu Yamamoto, Evan Borden
homepage: https://github.com/haskell/network
synopsis: Low-level networking interface
description:
    This package provides a low-level networking interface.
    .
    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:
    .
    > library
    >   build-depends: network-uri-flag
category: Network
abi: 54f69fdc31b327cbaedcff3f363b5d26
exposed: True
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal
hidden-modules: Network.Socket.ByteString.Internal
                Network.Socket.Types Network.Socket.ByteString.IOVec
                Network.Socket.ByteString.Lazy.Posix
                Network.Socket.ByteString.MsgHdr
import-dirs: /usr/lib/ghc-8.6.5/site-local/network-2.8.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/network-2.8.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/network-2.8.0.0
hs-libraries: HSnetwork-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2
include-dirs: /usr/lib/ghc-8.6.5/site-local/network-2.8.0.0/include
includes:
    HsNet.h HsNetDef.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2 unix-2.7.2.2
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces: /usr/share/doc/haskell-network/html/network.haddock
haddock-html: /usr/share/doc/haskell-network/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
